==> beast-0.5.5-rc3.tar.gz: beast-0.5.5-rc3/bse/bsecategories.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsecategories.proc"

#include <bse/bsecategories.h>
#include <bse/bseprocedure.h>
#include <bse/bseplugin.h>


#line 25 "bsecategories.proc"


/* --- bse-categories-match-typed --- */
static void
bse_categories_match_typed_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsecategories.proc"
 {
#line 29 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Base type for categories to conform to.",
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 28 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern and type match.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 35 "bsecategories.proc"
 }
static BseErrorType
#line 35 "bsecategories.proc"
bse_categories_match_typed_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 38 "bsecategories.proc"
{
#line 39 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType  type      = type_name ? g_type_from_name (type_name) : 0;
  BseCategorySeq *cseq = NULL;
  
#line 45 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  if (type)
    cseq = bse_categories_match_typed (pattern, type);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 54 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-categories-match --- */
static void
bse_categories_match_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 60 "bsecategories.proc"
 {
#line 62 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 61 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern match.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 66 "bsecategories.proc"
 }
static BseErrorType
#line 66 "bsecategories.proc"
bse_categories_match_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 69 "bsecategories.proc"
{
#line 70 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  BseCategorySeq *cseq = NULL;
  
#line 74 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  cseq = bse_categories_match_typed (pattern, 0);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 82 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-category-from-id --- */
static void
bse_category_from_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 88 "bsecategories.proc"
 {
#line 90 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_int ("category_id", "Category ID", NULL,
			 1, 1, G_MAXINT, 1, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("category", "Category", NULL, BSE_TYPE_CATEGORY, SFI_PARAM_DEFAULT);
}
#line 89 "bsecategories.proc"
  proc->help = "Find a BSE category from it's unique ID.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 94 "bsecategories.proc"
 }
static BseErrorType
#line 94 "bsecategories.proc"
bse_category_from_id_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 97 "bsecategories.proc"
{
#line 98 "bsecategories.proc"
  
  guint id = sfi_value_get_int (in_values++);
  BseCategory *cat;

  cat = bse_category_from_id (id);
  
#line 104 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cat);
  
  return BSE_ERROR_NONE;
}

static gboolean
categories_check_method (BseCategory *cat,
                         gpointer     data)
{
  GType *type_p = data;
  GType ptype = g_type_from_name (cat->type);
  gboolean match = FALSE;
  if (BSE_TYPE_IS_PROCEDURE (ptype))
    {
      BseProcedureClass *proc = g_type_class_ref (ptype);
      if (proc->n_in_pspecs >= 1 &&
          g_type_is_a (G_PARAM_SPEC_VALUE_TYPE (proc->in_pspecs[0]), *type_p))
        match = TRUE;
      g_type_class_unref (proc);
    }
  return match;
}

/* --- bse-categories-match-method --- */
static void
bse_categories_match_method_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 128 "bsecategories.proc"
 {
#line 130 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_DEFAULT);
  *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Object base type for methods to conform to.",
			    NULL, SFI_PARAM_DEFAULT);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_DEFAULT);
}
#line 129 "bsecategories.proc"
  proc->help = "List BSE categories according to a pattern, of type procedure and applying to a certain object type.";
#line 23 "bsecategories.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsecategories.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 136 "bsecategories.proc"
 }
static BseErrorType
#line 136 "bsecategories.proc"
bse_categories_match_method_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 139 "bsecategories.proc"
{
#line 140 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType  type      = type_name ? g_type_from_name (type_name) : 0;
  BseCategorySeq *cseq = NULL;
  
#line 146 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  cseq = bse_categories_match (pattern, BSE_TYPE_PROCEDURE, categories_check_method, &type);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 154 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_bse_categories_match_typed = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "bse-categories-match-typed", "/Proc/Categories/Match Typed", NULL },
  0, bse_categories_match_typed_setup, bse_categories_match_typed_exec, 
};
static BseExportNodeProc __enode_bse_categories_match = {
  { (BseExportNode*) &__enode_bse_categories_match_typed, BSE_EXPORT_NODE_PROC,
    "bse-categories-match", "/Proc/Categories/Match", NULL },
  0, bse_categories_match_setup, bse_categories_match_exec, 
};
static BseExportNodeProc __enode_bse_category_from_id = {
  { (BseExportNode*) &__enode_bse_categories_match, BSE_EXPORT_NODE_PROC,
    "bse-category-from-id", "/Proc/Categories/From ID", NULL },
  0, bse_category_from_id_setup, bse_category_from_id_exec, 
};
static BseExportNodeProc __enode_bse_categories_match_method = {
  { (BseExportNode*) &__enode_bse_category_from_id, BSE_EXPORT_NODE_PROC,
    "bse-categories-match-method", "/Proc/Categories/Match Method", NULL },
  0, bse_categories_match_method_setup, bse_categories_match_method_exec, 
};
BseExportNode* bse__builtin_init_bsecategories_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsecategories_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_bse_categories_match_method;
}

/**
 ** Generated data ends here
 **/

==> beast-0.5.6-rc1.tar.gz: beast-0.5.6-rc1/bse/bsecategories.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsecategories.proc"

#include <bse/bsecategories.h>
#include <bse/bseprocedure.h>
#include <bse/bseplugin.h>


#line 25 "bsecategories.proc"


/* --- bse-categories-match-typed --- */
static void
bse_categories_match_typed_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsecategories.proc"
 {
#line 29 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_STANDARD);
  *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Base type for categories to conform to.",
			    NULL, SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_STANDARD);
}
#line 35 "bsecategories.proc"
 }
static BseErrorType
#line 35 "bsecategories.proc"
bse_categories_match_typed_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 38 "bsecategories.proc"
{
#line 39 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType  type      = type_name ? g_type_from_name (type_name) : 0;
  BseCategorySeq *cseq = NULL;
  
#line 45 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  if (type)
    cseq = bse_categories_match_typed (pattern, type);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 54 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-categories-match --- */
static void
bse_categories_match_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 60 "bsecategories.proc"
 {
#line 62 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_STANDARD);
}
#line 66 "bsecategories.proc"
 }
static BseErrorType
#line 66 "bsecategories.proc"
bse_categories_match_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 69 "bsecategories.proc"
{
#line 70 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  BseCategorySeq *cseq = NULL;
  
#line 74 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  cseq = bse_categories_match_typed (pattern, 0);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 82 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- bse-category-from-id --- */
static void
bse_category_from_id_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 88 "bsecategories.proc"
 {
#line 90 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_int ("category_id", "Category ID", NULL,
			 1, 1, G_MAXINT, 1, SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_boxed ("category", "Category", NULL, BSE_TYPE_CATEGORY, SFI_PARAM_STANDARD);
}
#line 94 "bsecategories.proc"
 }
static BseErrorType
#line 94 "bsecategories.proc"
bse_category_from_id_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 97 "bsecategories.proc"
{
#line 98 "bsecategories.proc"
  
  guint id = sfi_value_get_int (in_values++);
  BseCategory *cat;

  cat = bse_category_from_id (id);
  
#line 104 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cat);
  
  return BSE_ERROR_NONE;
}

static gboolean
categories_check_method (BseCategory *cat,
                         gpointer     data)
{
  GType *type_p = data;
  GType ptype = g_type_from_name (cat->type);
  gboolean match = FALSE;
  if (BSE_TYPE_IS_PROCEDURE (ptype))
    {
      BseProcedureClass *proc = g_type_class_ref (ptype);
      if (proc->n_in_pspecs >= 1 &&
          g_type_is_a (G_PARAM_SPEC_VALUE_TYPE (proc->in_pspecs[0]), *type_p))
        match = TRUE;
      g_type_class_unref (proc);
    }
  return match;
}

/* --- bse-categories-match-method --- */
static void
bse_categories_match_method_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 128 "bsecategories.proc"
 {
#line 130 "bsecategories.proc"
  *(in_pspecs++) = sfi_pspec_string ("pattern", "Pattern", "Pattern to match category, supports '*' and '?' wildcards.",
			    "*", SFI_PARAM_STANDARD);
  *(in_pspecs++) = sfi_pspec_string ("type", "Type", "Object base type for methods to conform to.",
			    NULL, SFI_PARAM_STANDARD);
  *(out_pspecs++)   = bse_param_spec_boxed ("categories", "Categories", NULL, BSE_TYPE_CATEGORY_SEQ, SFI_PARAM_STANDARD);
}
#line 136 "bsecategories.proc"
 }
static BseErrorType
#line 136 "bsecategories.proc"
bse_categories_match_method_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 139 "bsecategories.proc"
{
#line 140 "bsecategories.proc"
  
  gchar *pattern   = sfi_value_get_string (in_values++);
  gchar *type_name = sfi_value_get_string (in_values++);
  GType  type      = type_name ? g_type_from_name (type_name) : 0;
  BseCategorySeq *cseq = NULL;
  
#line 146 "bsecategories.proc"
  
  if (!pattern)
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  cseq = bse_categories_match (pattern, BSE_TYPE_PROCEDURE, categories_check_method, &type);
  if (!cseq)
    cseq = bse_category_seq_new ();
  
#line 154 "bsecategories.proc"
  
  bse_value_take_boxed (out_values++, cseq);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_bse_categories_match_typed = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "bse-categories-match-typed", 
    NULL,
    "/Proc/Categories/Match Typed",
    "List BSE categories according to a pattern and type match.",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, bse_categories_match_typed_setup, bse_categories_match_typed_exec, 
};
static BseExportNodeProc __enode_bse_categories_match = {
  { (BseExportNode*) &__enode_bse_categories_match_typed, BSE_EXPORT_NODE_PROC,
    "bse-categories-match", 
    NULL,
    "/Proc/Categories/Match",
    "List BSE categories according to a pattern match.",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, bse_categories_match_setup, bse_categories_match_exec, 
};
static BseExportNodeProc __enode_bse_category_from_id = {
  { (BseExportNode*) &__enode_bse_categories_match, BSE_EXPORT_NODE_PROC,
    "bse-category-from-id", 
    NULL,
    "/Proc/Categories/From ID",
    "Find a BSE category from it's unique ID.",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, bse_category_from_id_setup, bse_category_from_id_exec, 
};
static BseExportNodeProc __enode_bse_categories_match_method = {
  { (BseExportNode*) &__enode_bse_category_from_id, BSE_EXPORT_NODE_PROC,
    "bse-categories-match-method", 
    NULL,
    "/Proc/Categories/Match Method",
    "List BSE categories according to a pattern, of type procedure and applying to a certain object type.",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, bse_categories_match_method_setup, bse_categories_match_method_exec, 
};
BseExportNode* bse__builtin_init_bsecategories_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsecategories_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_bse_categories_match_method;
}

/**
 ** Generated data ends here
 **/
